@@ -22,6 +22,9 @@
 
 
 
+#ifndef __GANN__
+#define __GANN__
+
 //Include Global Declarations
 #include "headers/gglobdec.h"
 
@@ -37,7 +40,7 @@ int main(int argc,char **argv)
     printf("-------------------------\n");
     printf("******   G.A.N.N   ******\n");
     printf("-------------------------\n");
-    printf("Version:1.1\n");
+    printf("Version:1.2\n");
     printf("=========================\n");
     printf("George Delaportas\n");
     printf("Dimitris Vlachos\n");
@@ -135,4 +138,6 @@ int main(int argc,char **argv)
 
 }
 
+#endif
+
 /* ------------------------------------------------------------------------ */
