@@ -22,6 +22,9 @@
 
 
 
+#if defined __GANN__
+#define __GNMS__
+
 //Geeks Neural Map Simulator (Function)
 void GNMS(int SimFunc)
 
@@ -96,7 +99,7 @@ void GNMS(int SimFunc)
         printf("--------------------------\n\n");
         
         //Start Simulation
-        printf("Learning...\n\n");
+        printf("Learning...\n");
         
         //Simulations Loop
         for (n=0;n<SimNum;n++)
@@ -107,7 +110,7 @@ void GNMS(int SimFunc)
             GNeuron *GANN;
             GANN=new GNeuron[MAX_MATRIX];
             
-            printf("* Simulation %i *\n\n",n+1);
+            printf("\n* Simulation %i *\n\n",n+1);
             
             //Escape Caption
             ReRoute:;
@@ -157,12 +160,17 @@ void GNMS(int SimFunc)
                                 //Get Data Or Data Range
                                 if (InSocket.GetPT(p)==0)
                                     Tmp=InSocket.GetPV(p,0);
+                                
                                 else
                                 
                                 {
                                 
-                                    Tmp=GGenData(1,InSocket.GetPV(p,0),\
-                                    InSocket.GetPV(p,1));
+                                    if (InSocket.GetPV(p,1)!=0.0)
+                                        Tmp=GGenData(2,InSocket.GetPV(p,0),\
+                                        InSocket.GetPV(p,1));
+                                    
+                                    else
+                                        Tmp=InSocket.GetPV(p,0);
                                 
                                 }
                                 
@@ -251,7 +259,7 @@ void GNMS(int SimFunc)
                 {
                 
                     //Produce A Registration Serial Number
-                    RegSerNum=abs((int)GGenData(1,\
+                    RegSerNum=abs((int)GGenData(2,\
                     (Inputs+Outputs)*(GNC+1)*time(0)*SimNum,0.0));
                     
                     //Initialize GSims
@@ -600,4 +608,6 @@ void GNMS(int SimFunc)
 
 }
 
+#endif
+
 /* ------------------------------------------------------------------------ */
