@@ -22,6 +22,9 @@
 
 
 
+#if defined __GANN__
+#define __GPTL__
+
 //Geeks Sleep (Function)
 void GSleep(int Sec);
 
@@ -210,4 +213,6 @@ void GExit(int ExitCode,char *ExitMsg);
 GSocket InSocket;		//Inputs GSocket
 GSocket OutSocket;		//Outputs GSocket
 
+#endif
+
 /* ------------------------------------------------------------------------ */
